@@ -12,9 +12,9 @@ def add_lib_to_dll_path(path):
     except (AttributeError,KeyError,FileNotFoundError):
         pass
 
-if 'OFF' == 'ON':
+if 'no' == 'ON':
+    add_lib_to_dll_path('')
     add_lib_to_dll_path('')
-    add_lib_to_dll_path('CUDA_CUDART_LIBRARY-NOTFOUND')
 
 from _dlib_pybind11 import *
 from _dlib_pybind11 import __version__, __time_compiled__
